package com.ruoyi.tc.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.tc.entity.AssetTask;
import com.ruoyi.tc.entity.Unit;
import com.ruoyi.tc.entity.request.GeneralQueryRequest;
import com.ruoyi.tc.entity.request.UnitRequest;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 单位信息（unit_info）表数据层
 * @author du
 * @since 2024/11/13 15:04
 */
public interface UnitMapper extends BaseMapper<Unit> {

    /**
     * 根据条件查询所有单位列表
     *
     * @param a 用户信息
     * @return 用户信息集合信息
     */
    List<Unit> selectUnitList(@Param("req") UnitRequest a);
    /**
     * 分页条件查询所有单位列表
     *
     * @param unit 用户信息
     * @return 用户信息集合信息
     */
    Page<Unit> selectUnitList(Page<Unit> page, @Param("req") UnitRequest unit);

    /**
     * 根据id列表查询单位
     */
    List<String> selectByIds(Long id);

    /**
     * 逻辑删除单位
     */
    void deleteUnits(Long  id);

    /**
     * 逻辑删除用户
     */
    void deleteUsers(@Param("userNames") String userNames);

    /**
     * 根据id获取详细信息
     */
    Unit getById(Long id);


    /**
     * 分页条件查询单位列表过滤
     *
     * @param unit 用户信息
     * @return 用户信息集合信息
     */
    Page<Unit> dwList(Page<Unit> page, @Param("req") UnitRequest unit);

    /**
     * 根据查询条件查询所有单位列表
     *
     * @param req 查询条件
     * @return 单位
     */
    List<Unit> selectAllUnit(@Param("req") GeneralQueryRequest req);




    /**
     * 根据单位查询资产总数
     *
     * @param part 单位
     * @return
     */
    Integer findBydwmc(@Param("part") String part);

    /**
     * 根据单位名称和5种资产类型查询
     */
    Integer selectTaskId(@Param("dwmc") String dwmc,@Param("type") String type);


    /**
     * app资产的单位组织架构不为空的部门
     */
    List<SysDept> getAppSchema();

    /**
     * email资产的单位组织架构不为空的部门
     */
    List<SysDept> getEmailSchema();


    /**
     * 小程序资产的单位组织架构不为空的部门
     */
    List<SysDept> getMiniSchema();


    /**
     * 公众号资产的单位组织架构不为空的部门
     */
    List<SysDept> getGzpSchema();


    /**
     * web资产的单位组织架构不为空的部门
     */
    List<SysDept> getWebSchema();
}
